@@ -342,6 +342,9 @@ def test_component_long_help() -> None:
         "  -e, --extra-args EXTRA_ARGS     Extra arguments to pass to the install\n"
         "                                  command\n"
         "  --path PATH                     Install Miniconda at the given path\n"
+        "  --python-match [major|minor|micro]\n"
+        "                                  Install the same version of Python,\n"
+        "                                  matching to the given version level\n"
         "  --spec SPEC                     Space-separated list of package\n"
         "                                  specifiers to install in the Miniconda\n"
         "                                  environment\n"
